{****************************************************************}
{*      The main unit of the SMTPDemo application.              *}
{*      Created by: Istvn Siroki                               *}
{****************************************************************}

{
 This unit has been created to demonstrate the usage of the SMTP client.
}

unit SMTP;

interface

uses
  Classes,
  IdBaseComponent, IdComponent, IdTCPConnection,
  IdTCPClient, IdExplicitTLSClientServerBase, IdMessageClient, IdSMTPBase,
  IdSMTP;

type
  TSMTPAttachment = String;
  TSMTPAttachments = array of TSMTPAttachment;

function SMTPSend(
  const ASMTPServerHost:        String;
  ASMTPServerPort:              Integer;
  const ASMTPServerUserName:    String;
  const ASMTPServerPassword:    String;
  const AFrom:                  String;
  const ARecipients:            String;
  const ACopyRecipients:        String;
  const ABlindCopyRecipients:   String;
  const ASubject:               String;
  const ABody:                  TStrings;
  const AAttachments:           TSMTPAttachments;
  out AErrorMessage:            String
): Boolean;

implementation

uses
  SysUtils, IdMessage, IdAttachment, IdAttachmentFile, IdSSLOpenSSL;

{********** Exported routines ************************************************}

{---------------------------------------------------------}
function SMTPSend(
  const ASMTPServerHost:        String;
  ASMTPServerPort:              Integer;
  const ASMTPServerUserName:    String;
  const ASMTPServerPassword:    String;
  const AFrom:                  String;
  const ARecipients:            String;
  const ACopyRecipients:        String;
  const ABlindCopyRecipients:   String;
  const ASubject:               String;
  const ABody:                  TStrings;
  const AAttachments:           TSMTPAttachments;
  out AErrorMessage:            String
): Boolean;
var
  IdSMTP:               TIdSMTP;
  IdMessage:            TIdMessage;
  IdAttachments:        array of TIdAttachment;
  i:                    Integer;
  SSLHandler:           TIdSSLIOHandlerSocketOpenSSL;
begin
  Result := True;
  AErrorMessage := '';
  SSLHandler := TIdSSLIOHandlerSocketOpenSSL.Create(nil);

  try
    IdSMTP := TIdSMTP.Create();
    IdMessage := TIdMessage.Create();

    SSLHandler.SSLOptions.Method := sslvTLSv1;
    SSLHandler.SSLOptions.Mode := sslmUnassigned;
    SSLHandler.SSLOptions.VerifyMode := [];
    SSLHandler.SSLOptions.VerifyDepth := 0;

    try
      with IdSMTP do begin
        Host := ASMTPServerHost;
        Port := ASMTPServerPort;
        Username := ASMTPServerUserName;
        Password := ASMTPServerPassword;
        IOHandler := SSLHandler;
        UseTLS := utUseExplicitTLS;
      end;
      with IdMessage do begin
        From.Address := AFrom;
        Recipients.EMailAddresses := ARecipients;
        CCLIst.EMailAddresses := ACopyRecipients;
        BCCList.EMailAddresses := ABlindCopyRecipients;
        Subject := ASubject;
        Body := ABody;
      end;
      SetLength(IdAttachments, Length(AAttachments));
      for i := 0 to High(AAttachments) do begin
        if not (FileExists(AAttachments[i])) then
          raise Exception.Create('The "' + AAttachments[i] +
            '" attached file does not exist.')
        else
           IdAttachments[i] := TIdAttachmentFile.Create(
             IdMessage.MessageParts, AAttachments[i]
           );
      end;
      IdSMTP.Connect;
      try
        IdSMTP.Send(IdMessage);
      finally
        IdSMTP.DisConnect;
      end;
    finally
      for i := 0 to High(IdAttachments) do
        IdAttachments[i].Free;
      IdMessage.Free;
      IdSMTP.Free;
      SSLHandler.Free;
    end;
  except
    on E:Exception do begin
      Result := False;
      AErrorMessage := 'E-mail sending error!' + #$D#$A + E.Message;
    end;
  end;
end;
{---------------------------------------------------------}

{*****************************************************************************}

end.
