{****************************************************************}
{*      The main form of the SMTPDemo application.              *}
{*      Created by: Istvn Siroki                               *}
{****************************************************************}

{
 This application is created to demonstrate the SMTP unit.
}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls, IdBaseComponent, IdComponent, IdTCPConnection,
  IdTCPClient, IdExplicitTLSClientServerBase, IdMessageClient, IdSMTPBase,
  IdSMTP;

type
  TForm1 = class(TForm)
    LabeledEdit1: TLabeledEdit;
    LabeledEdit2: TLabeledEdit;
    LabeledEdit3: TLabeledEdit;
    LabeledEdit4: TLabeledEdit;
    LabeledEdit5: TLabeledEdit;
    Label1: TLabel;
    Memo1: TMemo;
    Label2: TLabel;
    Button1: TButton;
    ListBox1: TListBox;
    Button2: TButton;
    Button3: TButton;
    Button4: TButton;
    LabeledEdit8: TLabeledEdit;
    LabeledEdit9: TLabeledEdit;
    LabeledEdit10: TLabeledEdit;
    LabeledEdit11: TLabeledEdit;
    Label3: TLabel;
    Button6: TButton;
    OpenDialog1: TOpenDialog;
    procedure Button1Click(Sender: TObject);
    procedure Button6Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses
  IniFiles, SMTP;

{********** Common routines ***************************************************}

{---------------------------------------------------------}
{Deletes all keys from a section of an ini file.
 (In fact does the same as EraseSection method but doesn't delete the section.)}
procedure IniFileDeleteKeys(AIniFile: TIniFile; const ASection: String);
var
  TmpStrList:   TStringList;
  i:            Integer;
begin
  TmpStrList := TStringList.Create;
  try
    AIniFile.ReadSection(ASection, TmpStrList);
    for i := 0 to TmpStrList.Count - 1 do
      AIniFile.DeleteKey(ASection, TmpStrList.Strings[i]);
  finally
    TmpStrList.Free;
  end;
end;
{---------------------------------------------------------}

{********** Application specific routines *************************************}

{---------------------------------------------------------}
procedure SaveDefault;
var
  IniFile:      TIniFile;
  i:            Integer;
begin
  IniFile := TIniFile.Create(ChangeFileExt(Application.ExeName, '.ini'));
  try
    with Form1, IniFile do begin
      WriteString('General', 'SMTPServerHost', LabeledEdit8.Text);
      WriteString('General', 'SMTPServerPort', LabeledEdit9.Text);
      WriteString('General', 'AuthenticationUserName', LabeledEdit10.Text);
      WriteString('General', 'AuthenticationPassword', LabeledEdit11.Text);
      WriteString('General', 'From', LabeledEdit1.Text);
      WriteString('General', 'To', LabeledEdit2.Text);
      WriteString('General', 'CopyTo', LabeledEdit3.Text);
      WriteString('General', 'BlindCopyTo', LabeledEdit4.Text);
      WriteString('General', 'Subject', LabeledEdit5.Text);

      IniFileDeleteKeys(IniFile, 'AttachedFiles');
      for i := 0 to ListBox1.Items.Count - 1 do
        WriteString('AttachedFiles', 'File' + IntToStr(i), ListBox1.Items[i]);

      IniFileDeleteKeys(IniFile, 'Body');
      for i := 0 to Memo1.Lines.Count - 1 do
        WriteString('Body', 'Line' + IntToStr(i), Memo1.Lines[i]);
    end;
  finally
    IniFile.Free;
  end;
end;
{---------------------------------------------------------}
procedure LoadDefault;
var
  IniFile:      TIniFile;     
  TmpStrList:   TStringList;
  i:            Integer;
begin
  IniFile := TIniFile.Create(ChangeFileExt(Application.ExeName, '.ini'));
  TmpStrList := TStringList.Create;
  try
    with Form1, IniFile do begin
      LabeledEdit8.Text  := ReadString('General', 'SMTPServerHost', '');
      LabeledEdit9.Text  := ReadString('General', 'SMTPServerPort', '');
      Label3.Caption     := '(Default ' + LabeledEdit9.Text + ')';
      LabeledEdit10.Text := ReadString('General', 'AuthenticationUserName', '');
      LabeledEdit11.Text := ReadString('General', 'AuthenticationPassword', '');
      LabeledEdit1.Text  := ReadString('General', 'From', '');
      LabeledEdit2.Text  := ReadString('General', 'To', '');
      LabeledEdit3.Text  := ReadString('General', 'CopyTo', '');
      LabeledEdit4.Text  := ReadString('General', 'BlindCopyTo', '');
      LabeledEdit5.Text  := ReadString('General', 'Subject', '');

      TmpStrList.Clear;
      ListBox1.Items.Clear;
      ReadSection('AttachedFiles', TmpStrList);
      for i := 0 to TmpStrList.Count - 1 do
        ListBox1.Items.Add(ReadString('AttachedFiles', TmpStrList.Strings[i], ''));

      TmpStrList.Clear;
      Memo1.Lines.Clear;
      ReadSection('Body', TmpStrList);
      for i := 0 to TmpStrList.Count - 1 do
        Memo1.Lines.Add(ReadString('Body', TmpStrList.Strings[i], ''));
    end;
  finally
    TmpStrList.Free;
    IniFile.Free;
  end;
end;
{---------------------------------------------------------}

{********** Event handlers ****************************************************}

{---------------------------------------------------------}
procedure TForm1.FormCreate(Sender: TObject);
begin
  OpenDialog1.InitialDir := ExtractFileDir(Application.ExeName);
  LoadDefault;
end;
{---------------------------------------------------------}
{Add a file attachment.}
procedure TForm1.Button1Click(Sender: TObject);
begin
  with OpenDialog1 do
    if Execute then
      ListBox1.Items.Add(FileName);
end;
{---------------------------------------------------------}
{Delete a file attachment.}
procedure TForm1.Button6Click(Sender: TObject);
begin
  ListBox1.DeleteSelected;
end;
{---------------------------------------------------------}
{Send.}
procedure TForm1.Button2Click(Sender: TObject);
var
  Attachments:  TSMTPAttachments;
  ErrorMessage: String;
  i:            Integer;
begin
  {Handle attached files.}
  SetLength(Attachments, ListBox1.Items.Count);
  for i := 0 to High(Attachments) do begin
    Attachments[i] := ListBox1.Items[i];
  end;

  {Send the e-mail.}
  if not SMTPSend(
    LabeledEdit8.Text,
    StrToInt(LabeledEdit9.Text),
    LabeledEdit10.Text,
    LabeledEdit11.Text,
    LabeledEdit1.Text,
    LabeledEdit2.Text,
    LabeledEdit3.Text,
    LabeledEdit4.Text,
    LabeledEdit5.Text,
    Memo1.Lines,
    Attachments,
    ErrorMessage)
  then
      ShowMessage(ErrorMessage);
end;
{---------------------------------------------------------}
{Save as Default.}
procedure TForm1.Button3Click(Sender: TObject);
begin
  SaveDefault;
end;
{---------------------------------------------------------}
{Load Default.}
procedure TForm1.Button4Click(Sender: TObject);
begin
  LoadDefault;
end;
{---------------------------------------------------------}

{******************************************************************************}


end.
